@@ -22,7 +22,7 @@ conTestF.conLM <- function(object, type = "A", neq.alt = 0, boot = "no", R = 999
   if(!(type %in% c("A","B","global"))) {
     stop("Restriktor ERROR: type must be \"A\", \"B\", or \"global\"")
   }
-  if(!(boot %in% c("no","residual","model.based","parametric","mix.weights"))) {
+  if(!(boot %in% c("no","residual","model.based","parametric"))) {
     stop("Restriktor ERROR: boot method unknown.")
   }
   if (boot == "residual") {
@@ -36,7 +36,7 @@ conTestF.conLM <- function(object, type = "A", neq.alt = 0, boot = "no", R = 999
   # response variable
   y <- as.matrix(model.org$model[, attr(model.org$terms, "response")])
   # sample size
-  n <- dim(X)[1]
+  #n <- dim(X)[1]
   # weights
   w <- weights(model.org)
   # unconstrained df
@@ -176,10 +176,20 @@ conTestF.conLM <- function(object, type = "A", neq.alt = 0, boot = "no", R = 999
                               bvec        = bvec, 
                               meq         = meq, 
                               meq.alt     = meq.alt)
-    #wt.mix <- wt.bar
-    #attributes(wt.mix) <- NULL
-    attr(pvalue, "wt.bar") <- wt.bar
-    attr(pvalue, "wt.bar.method") <- attr(wt.bar, "method")
+    
+    attr(pvalue, "wt.bar"                     ) <- as.numeric(wt.bar)
+    attr(pvalue, "wt.bar.method"              ) <- attr(wt.bar, "method")
+    attr(pvalue, "converged"                  ) <- attr(wt.bar, "converged")
+    attr(pvalue, "convergence_crit"           ) <- attr(wt.bar, "convergence_crit")
+    attr(pvalue, "total_bootstrap_draws"      ) <- attr(wt.bar, "total_bootstrap_draws")
+    attr(pvalue, "error.idx"                  ) <- attr(wt.bar, "error.idx")
+    attr(pvalue, "mix_weights_bootstrap_limit") <- attr(wt.bar, "mix_weights_bootstrap_limit")
+    
+    attr(pvalue, "wt_bar_chunk") <- attr(wt.bar, "wt_bar_chunk")
+    attr(pvalue, "chunk_size"  ) <- attr(wt.bar, "chunk_size_org")
+    attr(pvalue, "total_chunks") <- attr(wt.bar, "total_chunks")
+    attr(pvalue, "chunk_iter"  ) <- attr(wt.bar, "chunk_iter")
+    
    } else if (boot == "parametric") {
      
      if (!is.function(p.distr)) {
@@ -273,7 +283,7 @@ conTestLRT.conLM <- function(object, type = "A", neq.alt = 0, boot = "no", R = 9
   if(!(type %in% c("A","B","global"))) {
     stop("Restriktor ERROR: type must be \"A\", \"B\", or \"global\"")
   }
-  if(!(boot %in% c("no", "residual", "model.based", "parametric", "mix.weights"))) {
+  if(!(boot %in% c("no", "residual", "model.based", "parametric"))) {
     stop("Restriktor ERROR: boot method unknown.")
   }
   if (boot == "residual") {
@@ -291,7 +301,7 @@ conTestLRT.conLM <- function(object, type = "A", neq.alt = 0, boot = "no", R = 9
   # unconstrained df
   df.residual <- object$df.residual
   # unconstrained covariance matrix
-  Sigma <- vcov(model.org) 
+  #Sigma <- vcov(model.org) 
   # parameter estimates
   b.unrestr <- object$b.unrestr
   b.restr <- object$b.restr
@@ -360,7 +370,7 @@ conTestLRT.conLM <- function(object, type = "A", neq.alt = 0, boot = "no", R = 9
                                                  control$maxit))$qp$solution
     b.eqrestr[abs(b.eqrestr) < tol] <- 0L
     names(b.eqrestr) <- vnames
-    b.eqrestr <- as.vector(b.eqrestr)
+    #b.eqrestr <- as.vector(b.eqrestr)
     
     fitted0 <- X %*% b.eqrestr
     residuals0 <- y - fitted0
@@ -385,7 +395,7 @@ conTestLRT.conLM <- function(object, type = "A", neq.alt = 0, boot = "no", R = 9
                                                   control$maxit))$qp$solution
     b.eqrestr[abs(b.eqrestr) < tol] <- 0L
     names(b.eqrestr) <- vnames
-    b.eqrestr <- as.vector(b.eqrestr)
+    #b.eqrestr <- as.vector(b.eqrestr)
     
     fitted0 <- X %*% b.eqrestr
     residuals0 <- y - fitted0
@@ -452,7 +462,20 @@ conTestLRT.conLM <- function(object, type = "A", neq.alt = 0, boot = "no", R = 9
                               bvec        = bvec, 
                               meq         = meq, 
                               meq.alt     = meq.alt)
-    attr(pvalue, "wt.bar") <- wt.bar
+    
+    attr(pvalue, "wt.bar"                     ) <- as.numeric(wt.bar)
+    attr(pvalue, "wt.bar.method"              ) <- attr(wt.bar, "method")
+    attr(pvalue, "converged"                  ) <- attr(wt.bar, "converged")
+    attr(pvalue, "convergence_crit"           ) <- attr(wt.bar, "convergence_crit")
+    attr(pvalue, "total_bootstrap_draws"      ) <- attr(wt.bar, "total_bootstrap_draws")
+    attr(pvalue, "error.idx"                  ) <- attr(wt.bar, "error.idx")
+    attr(pvalue, "mix_weights_bootstrap_limit") <- attr(wt.bar, "mix_weights_bootstrap_limit")
+    
+    attr(pvalue, "wt_bar_chunk") <- attr(wt.bar, "wt_bar_chunk")
+    attr(pvalue, "chunk_size"  ) <- attr(wt.bar, "chunk_size_org")
+    attr(pvalue, "total_chunks") <- attr(wt.bar, "total_chunks")
+    attr(pvalue, "chunk_iter"  ) <- attr(wt.bar, "chunk_iter")
+
   } else if (boot == "parametric") {
     if (!is.function(p.distr)) {
       p.distr <- get(p.distr, mode = "function")
@@ -542,7 +565,7 @@ conTestScore.conLM <- function(object, type = "A", neq.alt = 0, boot = "no", R =
   if(!(type %in% c("A","B","global"))) {
     stop("Restriktor ERROR: type must be \"A\", \"B\", or \"global\"")
   }
-  if(!(boot %in% c("no", "residual", "model.based", "parametric", "mix.weights"))) {
+  if(!(boot %in% c("no", "residual", "model.based", "parametric"))) {
     stop("Restriktor ERROR: boot method unknown.")
   }
   if (boot == "residual") {
@@ -558,7 +581,7 @@ conTestScore.conLM <- function(object, type = "A", neq.alt = 0, boot = "no", R =
   # unconstrained df
   df.residual <- object$df.residual
   # unconstrained covariance matrix
-  Sigma <- vcov(model.org) 
+  #Sigma <- vcov(model.org) 
   # sample size
   n <- dim(X)[1]
   # number of parameters
@@ -786,7 +809,20 @@ conTestScore.conLM <- function(object, type = "A", neq.alt = 0, boot = "no", R =
                               bvec        = bvec, 
                               meq         = meq, 
                               meq.alt     = meq.alt)
-    attr(pvalue, "wt.bar") <- wt.bar
+    
+    attr(pvalue, "wt.bar"                     ) <- as.numeric(wt.bar)
+    attr(pvalue, "wt.bar.method"              ) <- attr(wt.bar, "method")
+    attr(pvalue, "converged"                  ) <- attr(wt.bar, "converged")
+    attr(pvalue, "convergence_crit"           ) <- attr(wt.bar, "convergence_crit")
+    attr(pvalue, "total_bootstrap_draws"      ) <- attr(wt.bar, "total_bootstrap_draws")
+    attr(pvalue, "error.idx"                  ) <- attr(wt.bar, "error.idx")
+    attr(pvalue, "mix_weights_bootstrap_limit") <- attr(wt.bar, "mix_weights_bootstrap_limit")
+    
+    attr(pvalue, "wt_bar_chunk") <- attr(wt.bar, "wt_bar_chunk")
+    attr(pvalue, "chunk_size"  ) <- attr(wt.bar, "chunk_size_org")
+    attr(pvalue, "total_chunks") <- attr(wt.bar, "total_chunks")
+    attr(pvalue, "chunk_iter"  ) <- attr(wt.bar, "chunk_iter")
+    
   } else if (boot == "parametric") {
     if (!is.function(p.distr)) {
       p.distr <- get(p.distr, mode = "function")
@@ -903,9 +939,6 @@ conTestC.restriktor <- function(object, ...) {
               boot        = "no",
               model.org   = object$model.org)
   
-#  OUT <- list(OUT)
-#    names(OUT) <- "C"
-  
   class(OUT) <- "conTest"
   
   OUT
